@@ -213,6 +213,9 @@ class Ui_MainWindow(QMainWindow):
 
         
     def search(self):
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
+        self.view.mousePressEvent(QMouseEvent ( QEvent.MouseButtonPress, QPoint(0,0), Qt.LeftButton, Qt.LeftButton, Qt.NoModifier ))
+        self.view.mouseReleaseEvent(QMouseEvent ( QEvent.MouseButtonRelease, QPoint(0,0), Qt.LeftButton, Qt.LeftButton, Qt.NoModifier ))
         self.stop()
         self.panDepart.hide()
         self.panArrivee.hide()
@@ -221,9 +224,10 @@ class Ui_MainWindow(QMainWindow):
         self.Temps.hide()
 
         cherche = classes.diagSearch(graph ,self.view)
-        QObject.connect(app.desktop(), SIGNAL("resized(int)"), cherche.rotate)
+        QObject.connect(self, SIGNAL("orientationChanged"), cherche.rotate)
         QObject.connect(cherche, SIGNAL("selected(QString)"), self.searchProcess)
         cherche.show()
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
 
     def searchProcess(self,text):
         self.panDepart.show()
@@ -239,6 +243,9 @@ class Ui_MainWindow(QMainWindow):
         
                     
     def selecLignes(self):
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
+        self.view.mousePressEvent(QMouseEvent ( QEvent.MouseButtonPress, QPoint(0,0), Qt.LeftButton, Qt.LeftButton, Qt.NoModifier ))
+        self.view.mouseReleaseEvent(QMouseEvent ( QEvent.MouseButtonRelease, QPoint(0,0), Qt.LeftButton, Qt.LeftButton, Qt.NoModifier ))
         self.stop()
         self.panDepart.hide()
         self.panArrivee.hide()
@@ -247,11 +254,12 @@ class Ui_MainWindow(QMainWindow):
         self.Temps.hide()
 
         graph.clear()
-        boole = (app.desktop().screenGeometry().width() < app.desktop().screenGeometry().height())
+        boole = (self.view.width() < self.view.height())
         ligne = classes.diagLigne(self.Lignes,boole,self.view)
         QObject.connect(ligne,SIGNAL("selection(PyQt_PyObject)"),self.selecLignesProcess)
-        QObject.connect(app.desktop(), SIGNAL("resized(int)"), ligne.rotate)
+        QObject.connect(self, SIGNAL("orientationChanged"), ligne.rotate)
         ligne.show()
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
         
     def selecLignesProcess(self,liste):
         reload(station)
@@ -292,6 +300,9 @@ class Ui_MainWindow(QMainWindow):
                 self.deselec('GPS')
 
     def about(self):
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
+        self.view.mousePressEvent(QMouseEvent ( QEvent.MouseButtonPress, QPoint(0,0), Qt.LeftButton, Qt.LeftButton, Qt.NoModifier ))
+        self.view.mouseReleaseEvent(QMouseEvent ( QEvent.MouseButtonRelease, QPoint(0,0), Qt.LeftButton, Qt.LeftButton, Qt.NoModifier ))
         self.stop()
         self.panDepart.hide()
         self.panArrivee.hide()
@@ -300,13 +311,17 @@ class Ui_MainWindow(QMainWindow):
         self.Temps.hide()
 
         about = classes.diagAbout(self.view)
-        QObject.connect(app.desktop(), SIGNAL("resized(int)"), about.rotate)
+        QObject.connect(self, SIGNAL("orientationChanged"), about.rotate)
         QObject.connect(about,SIGNAL("closing()"),self.endMenu)
         about.show()
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
 
 
 
     def aide(self):
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
+        self.view.mousePressEvent(QMouseEvent ( QEvent.MouseButtonPress, QPoint(0,0), Qt.LeftButton, Qt.LeftButton, Qt.NoModifier ))
+        self.view.mouseReleaseEvent(QMouseEvent ( QEvent.MouseButtonRelease, QPoint(0,0), Qt.LeftButton, Qt.LeftButton, Qt.NoModifier ))
         self.stop()
         self.panDepart.hide()
         self.panArrivee.hide()
@@ -315,9 +330,10 @@ class Ui_MainWindow(QMainWindow):
         self.Temps.hide()
 
         aide = classes.diagAide(self.view)
-        QObject.connect(app.desktop(), SIGNAL("resized(int)"), aide.rotate)
+        QObject.connect(self, SIGNAL("orientationChanged"), aide.rotate)
         QObject.connect(aide,SIGNAL("closing()"),self.endMenu)
         aide.show()
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
 
     def endMenu(self):
         self.panDepart.show()
@@ -584,7 +600,7 @@ class Ui_MainWindow(QMainWindow):
         Sy = (h/(dy+10))
         S = max(min(Sx,Sy,5.0),.21)
 
-        val = ((S) /self.view.getScale())**(.17)
+        val = ((S) /self.view.getScale())**(.1)
             
         animUnZoom = QPropertyAnimation (self.view, "scaling")
         animUnZoom.setDuration(_TEMPS_ANIM)
@@ -609,22 +625,20 @@ class Ui_MainWindow(QMainWindow):
         
 
     def orientationChanged(self, i):
-        self.panArrivee.move(self.panArrivee.x(),app.desktop().screenGeometry().height()-126)
-        self.panAction.move(self.panAction.x(),app.desktop().screenGeometry().height()/2-76)
+        self.emit(SIGNAL("orientationChanged"))
+        self.panArrivee.move(self.panArrivee.x(),self.view.height()-70)
+        self.panAction.move(self.panAction.x(),self.view.height()/2-48)
         self.view.translate(-150,200)
         
-        self.gpsButton.move(0,app.desktop().screenGeometry().height()-80-56)
+        self.gpsButton.move(0,self.view.height()-64)
 
         if self.panDepart.state :
-            self.panDepart.move(app.desktop().screenGeometry().width()-min(290,self.panDepart.width()),self.panDepart.y())
+            self.panDepart.move(self.view.width()-min(290,self.panDepart.width()),self.panDepart.y())
         if self.panArrivee.state :
-            self.panArrivee.move(app.desktop().screenGeometry().width()-min(290,self.panArrivee.width()),self.panArrivee.y())
+            self.panArrivee.move(self.view.width()-min(290,self.panArrivee.width()),self.panArrivee.y())
         if self.panAction.state :
-            self.panAction.move(app.desktop().screenGeometry().width()-100,self.panAction.y())
+            self.panAction.move(self.view.width()-100,self.panAction.y())
             self.panAction.animMargin.start()
-#        if self.panAction.toggle :  
-#            x = (app.desktop().screenGeometry().width() - self.Temps.width())/2
-#            self.Temps.move(x,app.desktop().screenGeometry().height() - 80 - 56)
 
     def buildGraph(self):
         toFix = []
@@ -717,11 +731,9 @@ class Ui_MainWindow(QMainWindow):
         self.scene.addPath(fleuve, QPen( QColor(165,191,221), _RAYON*.8))
 
     
-    def setupUi(self, App):
+    def setupUi(self, app):
         self.setWindowTitle("Rtap")
         self.resize(800,480)
-        global app
-        app = App
 
         self.centralWidget = QWidget(self)
         self.Selec = ('','')
@@ -756,16 +768,18 @@ class Ui_MainWindow(QMainWindow):
         self.panDepart = classes.PanStation(self.view)
         self.panDepart.setGeometry(900,0,250,180)
         QObject.connect(self.panDepart, SIGNAL("released(QString)"), self.deselec)
+        self.panDepart.setStyleSheet("background-color: qlineargradient(x1:3, y1:-1, x2:0, y2:1, stop:0 palette(light),  stop:1 palette(highlight)) ; color: palette(highlighted-text) ;border-left:3px solid palette(highlight); border-bottom:3px solid palette(highlight);")
         self.panDepart.show()
 
 
         self.panArrivee = classes.PanStation(self.view)
-        self.panArrivee.setGeometry(900,app.desktop().screenGeometry().height()-126,250,180)
+        self.panArrivee.setGeometry(900,self.view.height()-126,250,180)
         QObject.connect(self.panArrivee, SIGNAL("released(QString)"), self.deselec)
+        self.panArrivee.setStyleSheet("background-color: qlineargradient(x1:3, y1:2, x2:0, y2:0, stop:0 palette(light),  stop:1 palette(highlight)) ; color: palette(highlighted-text) ;border-left:3px solid palette(highlight); border-top:3px solid palette(highlight);")
         self.panArrivee.show()
 
         self.panAction = classes.PanAction(self.view)
-        self.panAction.setGeometry(900,app.desktop().screenGeometry().height()/2-56-20,80,80)
+        self.panAction.setGeometry(900,self.view.height()/2-56-20,80,80)
         QObject.connect(self.panAction, SIGNAL("colorise"), self.colorise)
         QObject.connect(self.panAction, SIGNAL("play"), self.play)
         self.panAction.show()
@@ -784,7 +798,7 @@ class Ui_MainWindow(QMainWindow):
         QObject.connect(self.gpsButton, SIGNAL("gpsOn"), self.addGPS)
         QObject.connect(self.gpsButton, SIGNAL("gpsOff"), self.closeSession)
         QObject.connect(self.gpsButton, SIGNAL("gpsCenter"), self.gpsCenter)
-        self.gpsButton.setGeometry(0,app.desktop().screenGeometry().height()-80-56,80,80)
+        self.gpsButton.setGeometry(0,self.view.height()-64-56,64,64)
         self.gpsButton.show()
 
 ######### Menu
@@ -810,7 +824,7 @@ class Ui_MainWindow(QMainWindow):
 
 #########
 
-        if app.desktop().screenGeometry().width() < app.desktop().screenGeometry().height():
+        if self.view.width() < self.view.height():
             self.view.centerOn(1900.,-500) 
         else:
             self.view.centerOn(1750.,-400)
